@@ -915,6 +915,43 @@ ID要强调当下分解的多样性？因为走势本身就是当下形成中的
 --摘自《2007-05-18 08:49 教你炒股票52：炒股票就是真正的学佛》
 """,
 
+
+    "100": """
+庄家和散户这种二元对立，大概比较适合现代中国人的思维模式，因此就变得如此的常识，但常
+识往往就是共同谬误的同义词，不仅是所谓的散户，而且很多的所谓庄家，也就牺牲其中。
+
+--摘自《2006-06-07 22:41 教你炒股票2：没有庄家，有的只是赢家和输家！》
+""",
+
+
+    "101": """
+真正的理性关心的不是介入的具体模式如何，而是这种模式如何被当下着，最重要的是，这种模
+式如何死去。
+
+对于市场的参与者来说，首要且时刻必须清楚自己目前介入模式的当下，而市场中的绝大多数人，
+是不知道自己在干什么的，狠一点说，就是死都不知道怎么死就死了，市场基本由这种人构成。
+
+--摘自《2006-06-19 21:41 教你炒股票4：什么是理性？今早买N中工就是理性！》
+""",
+
+    "102": """
+真正的猎手只会观察、操作，用嘴是打不了豺狼的。
+
+一个好的猎手，可以没有嘴巴，但一定会有一双不为外物所动的眼睛，在这眼睛下，一切如幻化
+般透明。要不被外物所动，则首先要不被自我所迷惑，其实无所谓外物、自我，都不过幻化空花，
+如此，方可从容其中。
+
+猎手只关心猎物，猎物不是分析而得的。猎物不是你所想到的，而是你看到的。相信你的眼睛，
+不要相信你的脑筋，更不要让你的脑筋动了你的眼睛。被脑筋所动的眼睛充满了成见，而所有的
+成见都不过对应着把你引向那最终陷阱的诱饵。猎手并不畏惧陷阱，猎手只是看着猎物不断地、
+以不同方式却共同结果地掉入各类陷阱，这里无所谓分析，只是看和干！
+
+猎手的好坏不是基于其能说出多少道道来，而是其置于其地的直觉。好的猎手不看而看，心物相
+通。
+
+--摘自《2006-06-21 20:52 教你炒股票5：市场无须分析，只要看和干！》
+""",
+
 }
 
 
