@@ -165,7 +165,7 @@ def byi_bi_end_V230107(c: CZSC, **kwargs) -> OrderedDict:
     return create_single_signal(k1=k1, k2=k2, k3=k3, v1=v1)
 
 
-def byi_second_bs_V230324(c: CZSC, di=1, **kwargs) -> OrderedDict:
+def byi_second_bs_V230324(c: CZSC, **kwargs) -> OrderedDict:
     """白仪二类买卖点辅助V230324
 
     参数模板："{freq}_D{di}MACD{fastperiod}#{slowperiod}#{signalperiod}回抽零轴_BS2辅助V230324"
@@ -223,3 +223,35 @@ def byi_second_bs_V230324(c: CZSC, di=1, **kwargs) -> OrderedDict:
     return create_single_signal(k1=k1, k2=k2, k3=k3, v1=v1)
 
 
+def byi_fx_num_V230628(c: CZSC, **kwargs) -> OrderedDict:
+    """白仪前面下跌或上涨一笔次级别笔结构数量满足条件；贡献者：谌意勇
+
+    参数模板："{freq}_D{di}笔分型数大于{num}_BE辅助V230628"
+
+    **信号逻辑：**
+
+    对于采用分型停顿或者分型验证开开仓，前一笔内部次级别笔结构尽量带结构，
+    此信号函数为当分型笔数量判断大于 num 为满足条件
+
+    **信号列表：**
+
+    - Signal('15分钟_D1笔分型数大于4_BE辅助V230628_向下_满足_任意_0')
+    - Signal('15分钟_D1笔分型数大于4_BE辅助V230628_向上_满足_任意_0')
+    
+    :param c: CZSC对象
+    :param di: 从倒数第几笔开始检查
+    :param num: 前笔内部次级别笔数量
+    :return: 信号识别结果
+    """
+    di = int(kwargs.get("di", 1))
+    num = int(kwargs.get('num', 4))
+    freq = c.freq.value
+    k1, k2, k3 = f"{freq}_D{di}笔分型数大于{num}_BE辅助V230628".split('_')
+    v1 = "其他"
+    if len(c.bi_list) < di + 1 or len(c.bars_ubi) > 7:
+        return create_single_signal(k1=k1, k2=k2, k3=k3, v1=v1)
+    
+    bi = c.bi_list[-di]
+    v1 = bi.direction.value
+    v2 = "满足" if len(bi.fxs) >= num else "其他"
+    return create_single_signal(k1=k1, k2=k2, k3=k3, v1=v1, v2=v2)
