@@ -10,9 +10,10 @@ from loguru import logger
 try:
     import talib as ta
 except:
-    logger.warning(f"ta-lib 没有正确安装，相关信号函数无法正常执行。"
-                   f"请参考安装教程 https://blog.csdn.net/qaz2134560/article/details/98484091")
+    logger.warning("ta-lib 没有正确安装，相关信号函数无法正常执行。"
+                   "请参考安装教程 https://blog.csdn.net/qaz2134560/article/details/98484091")
 import numpy as np
+import pandas as pd
 from typing import List
 from collections import OrderedDict
 from czsc.analyze import CZSC, RawBar
@@ -44,7 +45,7 @@ def update_vol_ma_cache(c: CZSC, ma_type: str, timeperiod: int, **kwargs):
     if cache_key not in last_cache.keys() or len(c.bars_raw) < timeperiod + 15:
         # 初始化缓存
         data = np.array([x.vol for x in c.bars_raw], dtype=np.float64)
-        ma = ta.MA(data, timeperiod=timeperiod, matype=ma_type_map[ma_type.upper()])
+        ma = ta.MA(data, timeperiod=timeperiod, matype=ma_type_map[ma_type.upper()]) # type: ignore
         assert len(ma) == len(data)
         for i in range(len(data)):
             _c = dict(c.bars_raw[i].cache) if c.bars_raw[i].cache else dict()
@@ -54,7 +55,7 @@ def update_vol_ma_cache(c: CZSC, ma_type: str, timeperiod: int, **kwargs):
     else:
         # 增量更新最近3个K线缓存
         data = np.array([x.vol for x in c.bars_raw[-timeperiod - 10:]], dtype=np.float64)
-        ma = ta.MA(data, timeperiod=timeperiod, matype=ma_type_map[ma_type.upper()])
+        ma = ta.MA(data, timeperiod=timeperiod, matype=ma_type_map[ma_type.upper()]) # type: ignore
         for i in range(1, 4):
             _c = dict(c.bars_raw[-i].cache) if c.bars_raw[-i].cache else dict()
             _c.update({cache_key: ma[-i]})
@@ -267,3 +268,96 @@ def vol_gao_di_V221218(c: CZSC, **kwargs) -> OrderedDict:
             break
 
     return create_single_signal(k1=k1, k2=k2, k3=k3, v1=v1, v2=v2)
+
+
+def vol_window_V230731(c: CZSC, **kwargs) -> OrderedDict:
+    """指定窗口内成交量的特征
+
+    参数模板："{freq}_D{di}W{w}M{m}N{n}_窗口能量V230731"
+
+    **信号逻辑：**
+
+    取最近 m 根K线，计算每根K线的成交量，分成n层，最大值为n，最小值为1；
+    最近 w 根K线的成交量分层最大值为max_vol_layer，最小值为min_vol_layer，
+    以这两个值作为窗口内的成交量特征。
+
+    **信号列表：**
+
+    - Signal('60分钟_D2W5M100N10_窗口能量V230731_高量N9_低量N4_任意_0')
+    - Signal('60分钟_D2W5M100N10_窗口能量V230731_高量N9_低量N5_任意_0')
+    - Signal('60分钟_D2W5M100N10_窗口能量V230731_高量N9_低量N2_任意_0')
+    - Signal('60分钟_D2W5M100N10_窗口能量V230731_高量N9_低量N3_任意_0')
+    - Signal('60分钟_D2W5M100N10_窗口能量V230731_高量N10_低量N4_任意_0')
+    - Signal('60分钟_D2W5M100N10_窗口能量V230731_高量N8_低量N3_任意_0')
+    - Signal('60分钟_D2W5M100N10_窗口能量V230731_高量N10_低量N3_任意_0')
+    - Signal('60分钟_D2W5M100N10_窗口能量V230731_高量N10_低量N6_任意_0')
+    - Signal('60分钟_D2W5M100N10_窗口能量V230731_高量N10_低量N7_任意_0')
+    - Signal('60分钟_D2W5M100N10_窗口能量V230731_高量N10_低量N5_任意_0')
+    - Signal('60分钟_D2W5M100N10_窗口能量V230731_高量N9_低量N6_任意_0')
+    - Signal('60分钟_D2W5M100N10_窗口能量V230731_高量N8_低量N2_任意_0')
+
+    :param c: CZSC对象
+    :param kwargs: 参数字典
+    
+        - :param di: 信号计算截止倒数第i根K线
+        - :param w: 观察的窗口大小。
+        - :param n: 分层的数量。
+        - :param m: 计算分位数所需取K线的数量。
+        
+    :return: 信号识别结果
+    """
+    di = int(kwargs.get("di", 1))
+    w = int(kwargs.get("w", 5))
+    m = int(kwargs.get("m", 30))
+    n = int(kwargs.get("n", 10))
+
+    freq = c.freq.value
+    k1, k2, k3 = f"{freq}_D{di}W{w}M{m}N{n}_窗口能量V230731".split('_')
+    v1 = "其他"
+
+    if len(c.bars_raw) < di + m:
+        return create_single_signal(k1=k1, k2=k2, k3=k3, v1=v1)
+
+    vols = [x.vol for x in get_sub_elements(c.bars_raw, di=di, n=m)]
+    vols_layer = pd.qcut(vols, n, labels=False, duplicates='drop')
+    max_vol_layer = max(vols_layer[-w:]) + 1
+    min_vol_layer = min(vols_layer[-w:]) + 1
+
+    v1, v2 = f"高量N{max_vol_layer}", f"低量N{min_vol_layer}"
+    return create_single_signal(k1=k1, k2=k2, k3=k3, v1=v1, v2=v2)
+
+
+def vol_window_V230801(c: CZSC, **kwargs) -> OrderedDict:
+    """指定窗口内成交量的特征
+
+    参数模板："{freq}_D{di}W{w}_窗口能量V230801"
+
+    **信号逻辑：**
+
+    观察一个固定窗口内的成交量特征，本信号以窗口内的最大成交量与最小成交量的先后顺序作为窗口成交量的特征。
+
+    **信号列表：**
+
+    - Signal('60分钟_D1W5_窗口能量V230801_先缩后放_任意_任意_0')
+    - Signal('60分钟_D1W5_窗口能量V230801_先放后缩_任意_任意_0')
+
+    :param c: CZSC对象
+    :param kwargs: 参数字典
+    
+        - :param di: 信号计算截止倒数第i根K线
+        - :param w: 观察的窗口大小。
+        
+    :return: 信号识别结果
+    """
+    di = int(kwargs.get("di", 1))
+    w = int(kwargs.get("w", 5))
+
+    freq = c.freq.value
+    k1, k2, k3 = f"{freq}_D{di}W{w}_窗口能量V230801".split('_')
+    if len(c.bars_raw) < di + w:
+        return create_single_signal(k1=k1, k2=k2, k3=k3, v1="其他")
+
+    vols = [x.vol for x in get_sub_elements(c.bars_raw, di=di, n=w)]
+    min_i, max_i = vols.index(min(vols)), vols.index(max(vols))
+    v1 = "先放后缩" if min_i > max_i else "先缩后放"
+    return create_single_signal(k1=k1, k2=k2, k3=k3, v1=v1)
